#
# spec file for package lxqt-session
#
# Copyright (c) 2015 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


Name:           lxqt-session
Version:        0.12.0
Release:        lp151.3.6
Summary:        LXQt Session Manager
License:        LGPL-2.1+
Group:          System/GUI/LXQt
Url:            http://www.lxqt.org
Source:         https://github.com/lxde/%{name}/releases/download/%{version}/%{name}-%{version}.tar.xz
Source1:        https://github.com/lxde/%{name}/releases/download/%{version}/%{name}-%{version}.tar.xz.asc
Source2:        %{name}.keyring
BuildRequires:  cmake >= 3.0.2
BuildRequires:  fdupes
BuildRequires:  gcc-c++
BuildRequires:  lxqt-build-tools-devel
BuildRequires:  cmake(KF5WindowSystem)
BuildRequires:  pkgconfig(Qt5UiTools)
BuildRequires:  pkgconfig(Qt5Xdg)
BuildRequires:  pkgconfig(lxqt) >= %{version} 
BuildRequires:  pkgconfig(libudev)
BuildRequires:  pkgconfig(x11)
BuildRequires:  pkgconfig(x11-xcb)
BuildRequires:  xdg-user-dirs
Requires(post): update-alternatives
Requires(postun): update-alternatives
Recommends:     %{name}-lang
Obsoletes:      lxqt-common
BuildRoot:      %{_tmppath}/%{name}-%{version}-build

%description
lxqt-session is the standard session manager used by LXQt. The lxqt-session manager
is used to automatically start a set of applications and set up a working desktop
environment. Moreover, the session manager is able to remember the applications in
use when a user logs out and to restart them the next time the user logs in.

%prep
%setup -q
# Changing LXQt into X-LXQt in desktop files to be freedesktop compliant and shut rpmlint warnings
#find -name '*desktop.in*' -exec sed -ri 's/(LXQt;)/X-\1/' {} +

%build
%cmake -DPULL_TRANSLATIONS=No
make %{?_smp_mflags}

%install
%cmake_install
%fdupes %{buildroot}/%{_datadir}

# for default-xsession
mkdir -p %{buildroot}%{_sysconfdir}/alternatives
touch %{buildroot}%{_sysconfdir}/alternatives/default-xsession.desktop
ln -s %{_sysconfdir}/alternatives/default-xsession.desktop %{buildroot}%{_datadir}/xsessions/default.desktop

%post
%{_sbindir}/update-alternatives --install %{_datadir}/xsessions/default.desktop \
  default-xsession.desktop %{_datadir}/xsessions/lxqt.desktop 20

%postun
[ -f %{_datadir}/xsessions/lxqt.desktop ] || %{_sbindir}/update-alternatives \
  --remove default-xsession.desktop %{_datadir}/xsessions/lxqt.desktop

%files
%defattr(-,root,root)
%doc AUTHORS LICENSE
%dir %{_sysconfdir}/xdg/
%dir %{_sysconfdir}/xdg/lxqt/
%dir %{_sysconfdir}/xdg/autostart
%dir %{_sysconfdir}/xdg/openbox
%dir %{_datadir}/kdm/
%dir %{_datadir}/kdm/sessions/
%{_bindir}/lxqt-config-session
%{_bindir}/lxqt-session
%{_bindir}/lxqt-leave
%{_datadir}/applications/*.desktop
%{_mandir}/man?/lxqt-*%{ext_man}
%config %{_sysconfdir}/xdg/autostart/lxqt-xscreensaver-autostart.desktop
%config %{_sysconfdir}/xdg/lxqt/lxqt.conf
%config %{_sysconfdir}/xdg/lxqt/session.conf
%config %{_sysconfdir}/xdg/lxqt/windowmanagers.conf
%config %{_sysconfdir}/xdg/openbox/lxqt-rc.xml
%{_bindir}/startlxqt
%{_datadir}/kdm/sessions/lxqt.desktop
%{_mandir}/man1/startlxqt.1%{ext_man}
%{_datadir}/xsessions/lxqt.desktop
# for default-xsession
%ghost %{_sysconfdir}/alternatives/default-xsession.desktop
%{_datadir}/xsessions/*.desktop

%changelog
* Tue May  8 2018 fabian@ritter-vogt.de
- Don't use %%fdupes -s as symlinks in the xsession directory have a
  special meaning (boo#1092251)
* Wed Oct 25 2017 mvetter@suse.com
- Add default-xsession which fvogt@suse.com added to
  (now deprecated) lxqt-common in the past
* Mon Oct 23 2017 mvetter@suse.com
- Update to 0.12.0:
  * Set patch version
  * lxqt-session: Unify arguments parsing
  * Don't export github templates
  * Add/Update Lithuanian language
  * c'n'p bug
  * add basic cli to lxqt-session
  * lxqt-session: Provide reboot/powerOff methods
  * Drops Qt5Core_VERSION_STRING
  * lxqt-config-session: set Qt::AA_UseHighDpiPixmaps to true
  * lxqt-leave: set Qt::AA_UseHighDpiPixmaps to true
  * improved --version
  * Added QCommandLineParser and basic cli interface to lxqt-conf-session
  * Added default CMAKE_BUILD_TYPE and LXQT_SESSION_PATCH_VERSION
  * String encoding (#103)
  * Fixes a FTBFS in superbuild mode (#102)
  * lxqt-leave: Fix "disabled items" key navigation
  * Address "unused parameter" compiler warnings
  * lxqt-leave: Redesign dialog for good key navigation
  * Removed superfluous include(LXQtTranslateDesktop)
  * fixed config/CMakeLists.txt
  * Merged relevant parts of CMakeLists.txt.lxqt-common into CMakeLists.txt
  * Rename CMakeLists.txt -> CMakeLists.txt.lxqt-common
  * Add Basque translation of lxqt-leave and update Basque translation of lxqt-config-session
  * leavedialog: Use "expected" tab order
  * LeaveDialog: Accept enter key for action/cancel firing
  * LeaveDialog: Use "override" keyword
  * leavedialog: Don't trigger "cancel" on Enter
  * LeaveDialog: Use correct method
  * startlxqt: Consider $XDG_RUNTIME_DIR/bus for DBus
  * Updated *_da.desktop files and removed *_da_DK.desktop files
  * Bump year
  * Update desktop entries and Replace fr_FR by fr
  * Use the LXQtConfigVars module
  * Fixed typo
  * Remove cpack (#61)
  * startlxqt: Consider LXQT_DEFAULT_OPENBOX_CONFIG
  * startlxqt: Honor the pre-defined SAL_USE_VLCPLUGIN
  * Replace lxqt-rc.xml with latest openbox version
  * startlxqt: Consider pre-exising LXDE OB config also
  * build: Revert @6d6d2bef54
  * build: Add xmessage as "dependency"
  * Openbox: Fix informational message about adoption of rc.xml
  * lxqt-rc.xml: Change default config install path
  * startlxqt: Copy existing openbox config preferably
  * Improves changed Openbox default path startup message (#51)
  * Disable gtk+ 3 overlay scrollbars by default.
  * Don't add XDG_DATA_HOME to XDG_DATA_DIRS (#47)
  * Message about Openbox default path changed.
  * Warning message about openbox settings path changed.
  * startlxqt: Force XDG_CONFIG_DIRS to contain @LXQT_ETC_XDG_DIR@
  * Copy openbox defaults at session start.
  * Rename openbox/rc.xml to openbox/lxqt-openbox-rc.xml
  * Openbox aero snap using mouse wheel over title bar.
  * Settings Openbox updated.
  * Default key shortcuts added to lxqt-globalkeysd.
  * CMakeLists: Use LXQT_GRAPHICS_DIR for graphics
  * Add startlxqt man page
  * Fixes #807 – Add XDG_CACHE_HOME definition
  * startlxqt: optimization of XDG_DATA_DIRS
  * corrected indentation
  * startlxqt: Set proper prefix for XDG_DATA_DIRS
  * Update Greek translation (el) Remove country variant from language code
  * Rename LxQt to LXQt everywhere
  * CMake: Adds Runtime and Devel install COMPONENTs
  * Coding style changes
  * Removes no added value comments
  * Adds double quotes to everything that may break
  * Use GNUINnstallDirs
  * Updates the build system to use the Targets infrastructure
  * Enable the "leave confirmation dialog" by default
  * TryExec to detect proper installed lxqt-session
  * Uniforms indentation
  * Sets env variable XDG_CONFIG_DIRS
  * Drops hardcoded /etc/xdg paths
  * Set LibreOffice's plugin env var to kde4
  * config: auto-detect succesfully kwin on recent kwin versions
  * Updated german translation, replaced Qt4 by Qt in all xsession/translations
  * Adds an scalable start-here-lxqt icon
  * use LXQt-specific menu file
  * Renames some .desktop files
  * Portuguese update for .desktop files
  * - Unify naming for a unique lxqt. No more suffixes
  * Make frost the default theme
  * Defines XDG_DATA_HOME and XDG_DATA_DIRS environment variables
  * Updates translations infrastructure
  * Update the required minimum cmake version
  * Clean up CMakeLists.txt and drop Qt 4 support
  * Set environment variable GTK_CSD=0 to turn off the default client side decoration for gtk+ 3 programs. (This will not always work if a gtk+3 program explicitly sets a title bar and turns on CSD.)
  * Add some more default values for Qt settings.
  * Update default config file.
  * Add Qt5 support.
  * Support Qt5 platform plugin and add some more comments.
  * Remove XDG_CURRENT_DESKTOP=Razor from environment variables.
  * Set XDG_CURRENT_DESKTOP to LXQt
  * remove dead template lines switch OnlyShowIn from Razor -> LXQt stringchanges LxQt -> LXQt
  * Use LXQt as desktop name
  * Add CPack rules for creating tarball
  * Add session.conf and windowmanagers.conf.
  * Change XDG_CURRENT_DESKTOP to Razor for now. (May rename to LxQt or something else in the future.)
  * Export environment varialbe QT_PLATFORM_PLUGIN=lxqt to let all Qt programs load lxqt-qtplugin and apply lxqt settings.
  * Support lxqt-session and add necessary xdg autostart desktop entry files.
  * Run lxde-qt with XDG_CURRENT_DESKTOP=RAZOR
  * Fix renaming bugs, replacing lxqt-qt with lxde-qt
  * Finish the crazy razor=>lxqt renaming tasks.
  * Rename dirs and replace razor with lxqt. Install lxqt.conf to /etc/xdg/lxqt and provide theme config.
  * Properly set default wallpaper for pcmanfm-qt. Comment out openbox config handling in startlxde-qt since it's not needed.
  * Remove custom openbox config file in desktop.conf temporarily until lxsession is fixed.
  * Fix file paths, replacing razor with lxqt. * Remove Alt+F2 and Ctrl+Esc from openbox config file to avoid conflicts with lxqt-panel & lxqt-globalkeys.
  * Add default configuration files for lxde-qt session.
- Remove because contained in new release:
  * lxqt-session-0.11.1-add-poweroff.patch
  * lxqt-session-0.11.1-string-encoding.patch
* Wed Sep 13 2017 mvetter@suse.com
- boo#1044483:
  * Add lxqt-session-0.11.1-string-encoding.patch
    to have new string encoding
  * Add lxqt-session-0.11.1-add-poweroff.patch
    add option to power off
* Fri Feb 24 2017 sfalken@opensuse.org
- Update to 0.11.1:
  * Adds an nullptr check when restarting a module (#90)
  * Fixes a session logout crash (#88)
  * Updated da.desktop files and removed da_DK.desktop files
  * Moves FindUDev to the lxqt-build-tools repo
  * Reworks X11 CMake libraries
  * Removes all XCB stuff from CMake
  * Update french desktop entries
  * lxqt-config-session: Use localized comment
  * Make CMakeLists.txt more uniform.
  * Remove cpack (#83)
* Sat Sep 24 2016 mvetter@suse.com
- Update to 0.11.0:
  * lockscreenmanager: always listen to the session provider's lock signal (#79)
  * Update Polish translation
  * Add README.md
  * lxqt-config-session: Warn about restart required when removing env variable
  * Add Catalan translations
  * lockscreenmanager: use categorized logger
  * Make screen locking before power actions optional
  * Add and Update Arabic Translations for Desktop Files
  * lxqt-session: Replace qCInfo() by qCWarning()
  * Adds an WITH_LIBUDEV CMake option (#74)
  * lockscreenmanager: add more log messages
  * Add logic to lock screen before system sleeps
  * lxqt-session: Use QLoggingCategory for logging/debug
  * lxqt-session: Use the base name to compare Wm's names
  * build: Use external translations
  * ts-files removal (#72)
  * Use const references with the foreach iterator
  * leave: ask or not for confirmation from main dialog
  * Adjust config dialog's size on startup
  * Make it compile using QT_USE_QSTRINGBUILDER
  * Fix lxqt-leave tab order
  * lxqt-session doesn't copy openbox defaults at session start. startlxqt from lxqt-common will copy it.
  * fixup...centering & spacing
  * leave: do not set maximum size as minimum size
  * Use XdgDir to find default path.
  * Openbox default settings removed.
  * Load LXQt default settings for Openbox.
  * UserLocations: An user entered empty string represents the default value
  * lxqt-config-session: Adds tooltips to the User Directories edits
  * lxqt-config-session: Replaces Locations by User Directories
  * Bump year Fix used licenses. lxqt-session is LGPL only
  * Re-arrange the buttons
  * lxqt-leave: Reworks window flags
  * lxqt-leave: Make all buttons of equal width
  * lxqt-leave: Center the dialog relative to the screen
  * lxqt-leave: Removes window border and makes it stay on top
  * lxqt-leave: Make the icons bigger and improves button alignement
  * Updated german translation.
  * Fix realloc() usage Check malloc() call result against NULL
  * Add HR translations
  * lxqt-session: Update man pages and make session the overview
  * Update italian translation
  * Updated Russian translations Removed ru_RU files
  * Makes the dependency on xdg-user-dirs-update explicit
  * Fix ending session and stopping modules
  * upd: lxqt-config-session_hu.ts del: lxt-config-session_hu_HU.ts
  * Fix desktop file
  * Make desktop files valid
  * CMakeLists.txt: Add cmake minimum required version
- Add keyring
- Remove 0001-Make-desktop-files-valid.patch: upstreamed
- Remove 0002-Fix-desktop-file.patch: upstreamed
* Fri Nov  6 2015 mvetter@suse.com
- Upstream release 0.10.0
- Adding patches to make desktop files valid:
  * 0001-Make-desktop-files-valid.patch
  * 0002-Fix-desktop-file.patch
- Removing patches:
  * fix_desktop_categories.patch - Using sed in spec file now.
* Fri Feb 20 2015 sfalken@opensuse.org
- Changed %%build and %%install to used cmake macros
* Mon Feb  9 2015 sfalken@opensuse.org
- New upstream version 0.9.0
- Added -lang subpackage
- Added Patch
  + fix_desktop_categories.patch - fixes category definitions to
  comply with openSUSE policy
* Mon Jan 26 2015 sfalken@opensuse.org
- Added conditionals to enable Fedora builds
* Sat Oct 25 2014 andrea@opensuse.org
- new upstream version 0.8.0
* Tue May 13 2014 sfalken@opensuse.org
- Specfile Cleanup
* Mon May 12 2014 sfalken@opensuse.org
-  Removed fedora specfile, split into subproject
  Del: lxqt-session-Fedora_20.spec
* Sat May 10 2014 sfalken@opensuse.org
- Ran spec-cleaner on openSUSE specfile
* Fri May  9 2014 sfalken@opensuse.org
- Added specfile for Fedora_20
  Add:  lxqt-session-Fedora_20.spec
* Fri May  9 2014 sfalken@opensuse.org
- Added tarball for new stable release
  Add:  lxqt-session-0.7.0.tar.xz
  Del:  _service
* Thu Apr  3 2014 sfalken@opensuse.org
- Initial Source Upload
  Add: _service
  Add: lxqt-session.spec
  Add: lxqt-session.changes
